//OSC signal receiver, built by Scott Brown - January 23, 2010
//Created to work with "Live 2 Processing" (Max4Live plugin)
//by WIGGLE (www.unsound.com)
//Plugin available at: http://www.unsound.com/M4L/

import oscP5.*;
import netP5.*;

OscP5 osc;
NetAddress remoteLocation;

//To store values used in draw()
float valueX;
float valueY;
int knobA;
int knobB;
int knobC;
int knobD;
int knobE;
int knobF;
boolean boxAClick = false;
boolean boxBClick = false;
boolean boxCClick = false;

void setup() {
  size(400, 200);
  
  //Open local OSC connection on port 12345
  osc = new OscP5(this, 12345);
  osc.plug(this, "varX", "/varX");
  osc.plug(this, "varY", "/varY");
  osc.plug(this, "knobA", "/knobA");
  osc.plug(this, "knobB", "/knobB");
  osc.plug(this, "knobC", "/knobC");
  osc.plug(this, "knobD", "/knobD");
  osc.plug(this, "knobE", "/knobE");
  osc.plug(this, "knobF", "/knobF");
  
  //For sending OSC data
  remoteLocation = new NetAddress("127.0.0.1", 12346);
}

void varX(float value) {
  println("varX "+value);
  valueX = value;
}

void varY(float value) {
  println("varY "+value);
  valueY = value;
}

void knobA(int value) {
  println("knobA "+value);
  knobA = value;
}

void knobB(int value) {
  println("knobB "+value);
  knobB = value;
}

void knobC(int value) {
  println("knobC "+value);
  knobC = value;
}

void knobD(int value) {
  println("knobD "+value);
  knobD = value;
}

void knobE(int value) {
  println("knobE "+value);
  knobE = value;
}

void knobF(int value) {
  println("knobF "+value);
  knobF = value;
}

void draw() {
  background(0);
  
  //Change background greyscale values depending on left and right channel peak values
  float backgroundLeft = map(valueX, 0, 100, 0, 255);
  float backgroundRight = map(valueY, 0, 100, 0, 255);
  
  noStroke();
  fill(90, 123, 108, backgroundLeft);
  rect(0, 0, width/2, height);
  fill(90, 123, 108, backgroundRight);
  rect(width/2, 0, width, height);
  
  //Change position of rect depending on knob values
  float boxA = map(knobA, 0, 127, height-40, 0);
  float boxB = map(knobB, 0, 127, height-40, 0);
  float boxC = map(knobC, 0, 127, height-40, 0);
  float boxD = map(knobD, 0, 127, height, 0);
  float boxE = map(knobE, 0, 127, height, 0);
  float boxF = map(knobF, 0, 127, height, 0);
  
  fill(255, 255, 241);
  rect(width-width/4-20, boxC, 40, 40);
  fill(55, 78, 90);
  rect(width/4-40, boxD, 80, 20);
  rect(width/2-40, boxE, 80, 20);
  rect(width-width/4-40, boxF, 80, 20);
  
  //Send boxClick data back to Live
  if (mouseX > width/4-20 && mouseX < width/4+20 && mouseY > boxA && mouseY < boxA+40 && mousePressed) {
    boxAClick = true;
    fill(150, 209, 182);
    rect(width/4-20, boxA, 40, 40);
    OscMessage boxAMessage = new OscMessage("/boxA");
    //boxAMessage.add(10);
    osc.send(boxAMessage, remoteLocation);
  } else {
    boxAClick = false;
    fill(255, 255, 241);
    rect(width/4-20, boxA, 40, 40);
  }
  
  if (mouseX > width/2-20 && mouseX < width/2+20 && mouseY > boxB && mouseY < boxB+40 && mousePressed) {
    boxBClick = true;
    fill(150, 209, 182);
    rect(width/2-20, boxB, 40, 40);
    OscMessage boxBMessage = new OscMessage("/boxB");
    //boxBMessage.add(10);
    osc.send(boxBMessage, remoteLocation);
  } else {
    boxBClick = false;
    fill(255, 255, 241);
    rect(width/2-20, boxB, 40, 40);
  }
  
  if (mouseX > width-width/4-20 && mouseX < width-width/4+20 && mouseY > boxC && mouseY < boxC+40 && mousePressed) {
    boxCClick = true;
    fill(150, 209, 182);
    rect(width-width/4-20, boxC, 40, 40);
    OscMessage boxCMessage = new OscMessage("/boxC");
    //boxCMessage.add(10);
    osc.send(boxCMessage, remoteLocation);
  } else {
    boxCClick = false;
    fill(255, 255, 241);
    rect(width-width/4-20, boxC, 40, 40);
  }
  
  
}
